Digestmap's Python bindings
===========================

A digestmap is an efficient mapping of content hashes (from SWHID to SHA1).
Designed after a `hash conversion service idea <https://docs.softwareheritage.org/devel/swh-digestmap/index.html>`_.

The Python package documented below contains bindings with the Rust crate
`swh-digestmap <https://crates.io/crates/swh-digestmap>`__.
Use the crate to create a digestmap.
